var isChrome = browser === undefined;
var browser = browser || chrome;

function showMessage(msg) {
    document.getElementById('message').classList.remove('hidden');
    document.getElementById('message').textContent = msg;
}

function saveOptions(e) {
    e.preventDefault();
    var enabled = document.querySelector("#enabled").checked;
    var instance = document.querySelector("#instance").value.trim();
    instance = instance.replace(/^https?:?\/?\/?/, '').replace('\/$');
    if (!instance) {
        showMessage("You must specify a domain");
        return;
    }

    let data = {
        enabled: enabled,
        instance: instance
    }

    console.log(`Saving data. Enabled = ${enabled}, Instance = ${instance}`);
    if(isChrome) {
        chrome.storage.sync.set(data, () => showMessage("Saved!"));
        return;
    }
    browser.storage.sync.set(data).then(() => {
        showMessage("Saved!");
    }, (error) => {
        // Try again with local storage instead
        browser.storage.local.set(data).then(() => {
            showMessage("Saved to local storage!");
        }, (error) => {
            showMessage(error);
        })
    });
}

function restoreOptions() {
    function setCurrentChoice(result) {
        document.querySelector("#enabled").checked = result.enabled;
        document.querySelector("#instance").value = result.instance;
    }

    function onLocalStorageError(error) {
        console.log("Failed to retrieve local storage. Falling back to Tor defaults");
        showMessage(error);
    }

    function onError(error) {
        console.log("Failed to retrieve settings from browser.storage.sync due to: " + error);
        console.log("Attempting to use local storage instead");
        let localStorageGetting = browser.storage.local.get(defaults);
        localStorageGetting.then(setCurrentChoice, onLocalStorageError);
    }


    let defaults = {
        enabled: true,
        instance: 'kiwifarmsaaf4t2h7gc3dfc5ojhmqruw2nit3uejrpiagrxeuxiyxcyd.onion',
    }

    if (isChrome) {
        chrome.storage.sync.get(defaults, (items) => {setCurrentChoice(items)})
        return;
    }
    let getting = browser.storage.sync.get(defaults);
    getting.then(setCurrentChoice, onError);
}

document.addEventListener("DOMContentLoaded", restoreOptions);
document.querySelector("form").addEventListener("submit", saveOptions);